==> openjdk-17_17.0.11~7ea.orig.tar.xz: openjdk-17-17.0.11~7ea/test/hotspot/jtreg/compiler/lib/ir_framework/driver/irmatching/parser/BlockLine.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package compiler.lib.ir_framework.driver.irmatching.parser;

import java.io.BufferedReader;
import java.util.regex.Pattern;

/**
 * Class representing a block line inside a PrintIdeal or PrintOptoAssembly output block read from the hotspot_pid* file.
 */
class BlockLine extends AbstractLine {

    public BlockLine(BufferedReader reader, Pattern compileIdPatternForTestClass) {
        super(reader, compileIdPatternForTestClass);
    }

    /**
     * Is this line an end of a PrintIdeal or PrintOptoAssembly output block?
     */
    public boolean isBlockEnd() {
        return line.startsWith("</");
    }
}

==> openjdk-19_19~20ea.orig.tar.xz: openjdk-19-19~20ea/test/hotspot/jtreg/compiler/lib/ir_framework/driver/irmatching/parser/BlockLine.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package compiler.lib.ir_framework.driver.irmatching.parser;

import java.io.BufferedReader;

/**
 * Class representing a block line inside a PrintIdeal or PrintOptoAssembly output block read from the hotspot_pid* file.
 */
class BlockLine extends AbstractLine {

    public BlockLine(BufferedReader reader) {
        super(reader);
    }

    /**
     * Is this line an end of a PrintIdeal or PrintOptoAssembly output block?
     */
    public boolean isBlockEnd() {
        return line.startsWith("</");
    }
}
